@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/croak/;
 use XSLoader;
 
-our $VERSION = '3.005'; # Don't forget to update the TestCompat set for testing against installed decoders!
+our $VERSION = '3.006'; # Don't forget to update the TestCompat set for testing against installed decoders!
 our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
 
 # not for public consumption, just for testing.
@@ -112,7 +112,7 @@ are ignored. They are otherwise recognized for compatibility only.
 The size threshold (in bytes) of the uncompressed output below which
 compression is not even attempted even if enabled.
 Defaults to one kilobyte (1024 bytes). Set this to 0 and C<compress> to
-a non-zero value to always attempt to compress.
+a non-C<SRL_UNCOMPRESSED> value to always attempt to compress.
 Note that the document will not be compressed if the resulting size
 will be bigger than the original size (even if C<compress_threshold> is 0).
 
@@ -257,6 +257,9 @@ less than 16 items, and and is not referenced more than once. This flag will
 override this optimization and use a standard REFN ARRAY style tag output. This
 is primarily useful for producing canoncial output and for testing Sereal itself.
 
+See L</CANONICAL REPRESENTATION> for why you might want to use this, and
+for the various caveats involved.
+
 =head3 sort_keys
 
 Normally C<Sereal::Encoder> will output hashes in whatever order is convenient,
@@ -620,6 +623,65 @@ compact that can represent your floating point number correctly.
 
 =back
 
+There's also a few cases where Sereal will produce different documents
+for values that you might think are the same thing, because if you
+e.g. compared them with C<eq> or C<==> in perl itself would think they
+were equivalent. However for the purposes of serialization they're not
+the same value.
+
+A good example of these cases is where L<Test::Deep> and Sereal's
+canonical mode differ. We have tests for some of these cases in
+F<t/030_canonical_vs_test_deep.t>. Here's the issues we've noticed so
+far:
+
+=over 4
+
+=item Sereal considers ASCII strings with the UTF-8 flag to be different from the same string without the UTF-8 flag
+
+Consider:
+
+    my $language_code = "en";
+
+v.s.:
+
+    my $language_code = "en";
+    utf8::upgrade($en);
+
+Sereal's canonical mode will encode these strings differently, as it
+should, since the UTF-8 flag will be passed along on interpolation.
+
+But this can be confusing if you're just getting some user-supplied
+ASCII strings that you may inadvertently toggle the UTF-8 flag on,
+e.g. because you're comparing an ASCII value in a database to a value
+submitted in a UTF-8 web form.
+
+=item Sereal will encode strings that look like numbers as strings, unless they've been used in numeric context
+
+I.e. these values will be encoded differently, respectively:
+
+    my $IV_x = "12345";
+    my $IV_y = "12345" + 0;
+    my $NV_x = "12.345";
+    my $NV_y = "12.345" + 0;
+
+But as noted above something like Test::Deep will consider these to be
+the same thing.
+
+=back
+
+We might produce certain aggressive flags to the canonical mode in the
+future to deal with this. For the cases noted above some combination
+of turning the UTF-8 flag on on all strings, or stripping it from
+strings that have it but are ASCII-only would "work", similarly we
+could scan strings to see if they match C<looks_like_number()> and if
+so numify them.
+
+This would produce output that either would be a lot bigger (having to
+encode all numbers as strings), or would be more expensive to generate
+(having to scan strings for numeric or non-ASCII context), and for
+some cases like the UTF-8 flag munging wouldn't be suitable for
+general use outside of canonicialization.
+
 =back
 
 Often, people don't actually care about "canonical" in the strict sense
@@ -631,6 +693,51 @@ which is simply serializing a cache key, and thus there's little harm in an
 occasional false-negative, but think carefully before applying Sereal in other
 use-cases.
 
+=head1 KNOWN ISSUES
+
+=over 4
+
+=item Strings Or Numbers
+
+Perl does not make a strong distinction between strings and numbers, and from
+an internal point of view it can be difficult to tell what the "right"
+representation is for a given variable.
+
+Sereal tries to not be lossy. So if it detects that the string value of a var,
+and the numeric value are different it will generally round trip the *string*
+value. This means that "special" strings often used in Perl function returns,
+like "0 but true", and "0e0", will round trip in a way that their normal Perl
+semantics are preserved. However this also means that "non canonical" values,
+like " 100 ", which will numify as 100 without warnings, will round trip as
+their string values.
+
+Perl also has some operators, the binary operators, ^, | and &, which do different
+things depending on whether their arguments had been used in numeric context as
+the following examples show:
+
+    perl -le'my $x="1"; $i=int($x); print unpack "H*", $x ^ "1"'
+    30
+
+    perl -le'my $x="1"; print unpack "H*", $x ^ "1"'
+    00
+
+    perl -le'my $x=" 1 "; $i=int($x); print unpack "H*", $x ^ "1"'
+    30
+
+    perl -le'my $x=" 1 "; print unpack "H*", $x ^ "1"'
+    113120
+
+Sereal currently cannot round trip this property properly.
+
+An extreme case of this problem is that of "dualvars", which can be created using
+the Scalar::Util::dualvar() function. This function allows one to create variables
+which have string and integer values which are completely unrelated to each other.
+Sereal currently will choose the *string* value when it detects these items.
+
+It is possible that a future release of the protocol will fix these issues.
+
+=back 4
+
 =head1 BUGS, CONTACT AND SUPPORT
 
 For reporting bugs, please use the github bug tracker at
